This folder contains scripts to facilitate using the code. We used Micromamba for creating virtual environments in Python. 

You can install simply install Micromamba by running:

```
chmod +x ./install_micromamba.sh
./install_micromamba.sh
```

Also to create an environment called `aftab_experiments` with `aftab` package automatically installed you can run the corresponding file:

```
chmod +x ./setup_environment.sh
./setup_environment.sh
```